import React from 'react';
import AppStore from "./../../../stores/AppStore";
import Keyboard from 'react-simple-keyboard';
import 'react-simple-keyboard/build/css/index.css';
import axios from 'axios';
import { properties } from '../../../properties.js';
import CheckinProzess from '../QRScan/CheckinProzess';
import LanguageStore from "./../../../stores/LanguageStore";

class Logistic extends React.Component {

  constructor(props) {
    super(props);

    this.state = {
      display: AppStore.getDisplay(),
      layoutName: "default",
      inputName:"",
      input: {}
    };

    this.log_type ="delivery"

    this.layout = {
        default: [
          "1 2 3 4 5 6 7 8 9 0 \u00DF \u00B4 {bksp}",
          "q w e r t z u i o p \u00FC ",
          "a s d f g h j k l \u00F6 \u00E4 ",
          "{shift} < y x c v b n m , . - ",
          "{space} @"
        ],
        shift: [
          '\u00B0 ! " \u00A7 $ % & / ( ) = ? ` {bksp}',
          "Q W E R T Z U I O P \u00DC *",
          "A S D F G H J K L \u00D6 \u00C4",
          "{shift} > Y X C V B N M ; : _ }",
          "{space} @"
        ]
      };

    this.update = this.update.bind(this);
    this.submit = this.submit.bind(this);
    this.changeType = this.changeType.bind(this);
    this.saveInputValues = this.saveInputValues.bind(this);
    this.afterPost = this.afterPost.bind(this);

    this.ap = null;
    this.au = null;
   }

   saveInputValues(inputName, val){
     let updatedInputObj = {
       ...this.state.input,
       [inputName]: val
     }

     this.setState(
       {
         input: updatedInputObj
       },
       () => {
         this.keyboardRef.keyboard.setInput(val);
       }
     );
   }

   handleChange(event) {}

   onChangeAll = inputObj => {
     this.setState({
       input: inputObj
     });
   };

   onKeyPress = button => {
     if (button === "{shift}" || button === "{lock}") this.handleShift();
   };

   handleShift = () => {
     let layoutName = this.state.layoutName;

     this.setState({
       layoutName: layoutName === "default" ? "shift" : "default"
     });
   };

   onChangeInput = event => {
     this.saveInputValues(this.state.inputName, event.target.value);
   };

   setActiveInput = (e) => {
     let inputName = e.target.name;
       this.setState({
         inputName: inputName
       }, () => {
         console.log("Active input", inputName);
       });
     }

  componentDidMount (){
    AppStore.load();
    AppStore.on("loaded", this.update);
  }

  update(){
    this.setState({
      display : AppStore.getDisplay(),
    })
  }

  submit(event){

    event.preventDefault();
    var inputs = this.state.input;
    var log_data = {};

    log_data.number = inputs.log_number;
    log_data.log_type = inputs.log_type;
    log_data.plate = inputs.log_truck_plate;
    log_data.trailer_plate = inputs.log_trailer_plate;
    log_data.driver_firstname = inputs.log_firstname;
    log_data.driver_lastname = inputs.log_name;

    log_data.ship_agency = inputs.log_spedition;
    log_data.driver_tel_number = inputs.log_mobile;

    const queryString = require('query-string');
    const parsed = queryString.parse(window.location.search);
    var display_id = parsed.di_id;

    var sendData = ["log_data" ];
    sendData = {
      'log_data' : log_data,
      'di_id' : display_id
    };

    axios({
        method: 'post',
        url: properties.api_url + "/logistic/?SID=" + properties.key,
        data: JSON.stringify(sendData),
        config: { headers: {'Content-Type': 'multipart/form-data' }}
        })
      .then(this.afterPost).catch(function (error) {
        var error_str = "<div className='e'>" + error.message + " <br> "
         error_str += error.request.responseURL+ " </div>"
        window.$("#error_message").append(error_str);
      })
  }

  afterPost(res){

    this.ap = res.data.ap;
    this.au = res.data.au;
    this.setState({
      done:'done'
    });
  }

  changeType(type){

    this.log_type = type;

    window.$(".selected").removeClass("selected");
    window.$("." + type).addClass("selected");

    window.$('.show').removeClass("show");
    window.$('#log_number').addClass("show");
    window.$('#log_number_txt').focus();
  }

  render() {

    if(this.state.done === "done"){

      return (
        <div id="logistic_mod" className="main_view main_content">
          <CheckinProzess ap={this.ap} au={this.au} />
        </div>
      )

    }

    return (
      <div id="logistic_mod" className="main_view main_content">
        <form onSubmit={this.submit}>
          <div class="accordion" id="logistic_acc">
            <div class="card" >
              <div class="card-header" id="heading_log_type">
                <h2 class="mb-0123123">
                  <button class="btn btn-link" type="button" data-toggle="collapse" data-target="#log_type" aria-expanded="false">
                    {LanguageStore.translate("Logistic_log_type")} &#43;
                  </button>
                </h2>
              </div>
              <div id="log_type" class="collapse show" aria-labelledby="heading_log_type" data-parent="#logistic_acc">
                <div class="card-body" className="log_type">
                  <button type="button" className="btn btn-light delivery selected" onClick={()=>this.changeType('delivery')}>{LanguageStore.translate("Logistic_log_type_delivery")}</button>
                  <button type="button" className="btn btn-light pickup" onClick={()=>this.changeType('pickup')}>{LanguageStore.translate("Logistic_log_type_pickup")}</button>
                </div>
              </div>
            </div>
            <div class="card">
              <div class="card-header" id="heading_log_number">
                <h2 class="mb-0123123">
                  <button class="btn btn-link collapsed" type="button" data-toggle="collapse" data-target="#log_number" aria-expanded="false">
                    {LanguageStore.translate("Logistic_log_number")} &#43;
                  </button>
                </h2>
              </div>
              <div id="log_number" class="collapse" aria-labelledby="heading_log_number" data-parent="#logistic_acc">
                <div class="card-body">
                  <div class="form-group">
                    <label>{LanguageStore.translate("Logistic_log_number")}</label>
                    <input
                      name="log_number"
                      type="text"
                      class="form-control"
                      id="log_number_txt"
                      placeholder={LanguageStore.translate("Logistic_log_number")}
                      onChange={e => this.onChangeInput(e)}
                      onFocus={ e => this.setActiveInput(e)}
                      value={this.state.input['log_number'] || ""}
                      />
                  </div>
                </div>
              </div>
            </div>
            <div class="card">
              <div class="card-header" id="heading_log_driver">
                <h2 class="mb-0123123">
                  <button class="btn btn-link collapsed" type="button" data-toggle="collapse" data-target="#log_driver" aria-controls="log_driver" aria-expanded="false">
                    {LanguageStore.translate("Logistic_driver")} &#43;
                  </button>
                </h2>
              </div>
              <div id="log_driver" class="collapse" aria-labelledby="heading_log_driver" data-parent="#logistic_acc">

                <div class="card-body">
                  <div class="form-group">
                    <label>{LanguageStore.translate("Logistic_driver_firstname")}</label>
                    <input
                      type="text"
                      class="form-control"
                      id="log_firstname"
                      name="log_firstname"
                      placeholder={LanguageStore.translate("Logistic_driver_firstname")}
                      onChange={e => this.onChangeInput(e)}
                      onFocus={ e => this.setActiveInput(e)}
                      value={this.state.input['log_firstname'] || ""}
                      required />
                  </div>

                  <div class="form-group">
                    <label>{LanguageStore.translate("Logistic_driver_lastname")}</label>
                    <input
                      type="text"
                      class="form-control"
                      id="log_name"
                      name="log_name"
                      placeholder={LanguageStore.translate("Logistic_driver_lastname")}
                      onChange={e => this.onChangeInput(e)}
                      onFocus={ e => this.setActiveInput(e)}
                      value={this.state.input['log_name'] || ""}
                      required />
                  </div>

                  <div class="form-group">
                    <label>{LanguageStore.translate("Logistic_agency")}</label>
                    <input
                      type="text"
                      class="form-control"
                      id="log_spedition"
                      name="log_spedition"
                      placeholder={LanguageStore.translate("Logistic_agency")}
                      onChange={e => this.onChangeInput(e)}
                      onFocus={ e => this.setActiveInput(e)}
                      value={this.state.input['log_spedition'] || ""}
                      required />
                  </div>

                  <div class="form-group">
                    <label>{LanguageStore.translate("Logistic_driver_mobile")}</label>
                    <input
                      type="text"
                      class="form-control"
                      id="log_mobile"
                      name="log_mobile"
                      placeholder={LanguageStore.translate("Logistic_driver_mobile")}
                      onChange={e => this.onChangeInput(e)}
                      onFocus={ e => this.setActiveInput(e)}
                      value={this.state.input['log_mobile'] || ""}
                      />
                  </div>

                  <div class="form-group">
                    <label>{LanguageStore.translate("Logistic_driver_truck")}</label>
                    <input
                      type="text"
                      class="form-control"
                      id="log_truck_plate"
                      name="log_truck_plate"
                      placeholder={LanguageStore.translate("Logistic_driver_truck")}
                      onChange={e => this.onChangeInput(e)}
                      onFocus={ e => this.setActiveInput(e)}
                      value={this.state.input['log_truck_plate'] || ""}
                      required />
                  </div>

                  <div class="form-group">
                    <label>{LanguageStore.translate("Logistic_driver_trailer")}</label>
                    <input
                      type="text"
                      class="form-control"
                      id="log_trailer_plate"
                      name="log_trailer_plate"
                      placeholder={LanguageStore.translate("Logistic_driver_trailer")}
                      onChange={e => this.onChangeInput(e)}
                      onFocus={ e => this.setActiveInput(e)}
                      value={this.state.input['log_trailer_plate'] || ""}
                      required />
                  </div>

                </div>
              </div>
            </div>
          </div>
          <div class="fixed">
            <button type="submit" className="btn btn-primary finish" >{LanguageStore.translate("Logistic_post")}</button>
            <div className="vkeyboard">
              <Keyboard
                layout={this.layout}
                ref={r => (this.keyboardRef = r)}
                layoutName={this.state.layoutName}
                inputName={this.state.inputName}
                onChangeAll={inputObj => this.onChangeAll(inputObj)}
                onKeyPress={button => this.onKeyPress(button)}
              />
            </div>
          </div>
        </form>

      </div>
    );
  }
}

export default Logistic;
